/*!
 * Widget Generator
 */
( function( win ) {
	jQuery( function( $ ) {
		var $generator = $( '#rss-widget-generator' ),
			$options_form = $generator.find( '.generator-options form' ),
			$widget_preview = $generator.find( '.widget-preview' );

		// auto select generated widget code
		var $widget_code = $generator.find( '.widget-code' ).on( 'click', function() {
			$( this ).select();
		} )
		// Widget Code generation
		.on( 'rss-fwg-generate', function() {
			try {
				var new_settings = $options_form.serializeObject();

				var generated_code = "<!-- RSS Feed Widget START -->\n" +
						"<!-- jQuery -->\n" +
						"<script type='text/javascript'>\n" +
						"/* <![CDATA[ */\n" +
						"window.jQuery || document.write( '<script src=\"//ajax.googleapis.com/ajax/libs/jquery/1.11.1/jquery.min.js\">\\x3C/script>' );\n" +
						"/* ]]> */\n" +
						"</script>" +
						"<!-- Widget Script -->\n" +
						"<script type='text/javascript' src='"+ feedpress_generator_generator.widget_script_uri +"'></script>\n" +
						"<!-- Widget Options -->\n" +
						"<script type='text/javascript'>\n" +
						"/* <![CDATA[ */\n" +
						"( function( win ) {\n" +
						"    jQuery( function( $ ) {\n"+
						"        feedpress_generator_widget_feed.start( " + json_encode( new_settings, null, 4 ) +", '"+ feedpress_generator_feed_defaults.endpoint +"' );\n" +
						"    } );\n" +
						"} )( window );\n" +
						"/* ]]> */\n" +
						"</script>\n" +
						"<!-- Widget holder -->\n" +
						"<div id='"+ new_settings.widget_id +"'><div>\n" +
						"<!-- RSS Feed Widget END -->";

				// update textarea
				$( this ).val( generated_code );

				// parse default settings values
				new_settings = $.extend( {}, feedpress_generator_feed_defaults.settings, new_settings );

				// run code preview
				feedpress_generator_widget_feed.start( new_settings, feedpress_generator_feed_defaults.endpoint );
			} catch ( ex ) {
				trace( ex.message );
			}
		} );

		// generate code onload
		setTimeout( function() {
			$widget_code.trigger( 'rss-fwg-generate' );
		}, 500 );

		// generate code on changes
		$generator.find( '.generator-options' ).on( 'change', ':input', function() {
			setTimeout( function() {
				$widget_code.trigger( 'rss-fwg-generate' );
			}, 300 );
		} );

		// entry limit checkbox
		var $entry_limit = $( '#entry_limit' );
		$( '#entry-limit-show-all' ).on( 'change', function( e ) {
			var $this = $( this );

			if ( e.target.checked ) {
				// save current value for later
				$this.data( 'previous-value', $entry_limit.val() );

				// disable the field and set value to 0
				$entry_limit.prop( 'disabled', true ).val( '0' );
			} else {
				// re-enable limit field and set it's value to previous value
				$entry_limit.prop( 'disabled', false ).val( $this.data( 'previous-value' ) );
			}
		} );

		// generate button
		$generator.find( '.widget-generate' ).on( 'click', function( e ) {
			e.preventDefault();
			$widget_code.trigger( 'rss-fwg-generate' );
		} );

		// custom css examples
		$generator.find( 'input[name=custom_css_examples]' ).on( 'change', function() {
			$generator.find( 'input[name=custom_css]' ).val( this.value );
		} );

		// clear custom css selection
		$generator.find( '.css-example-clear' ).on( 'click', function() {
			$generator.find( 'input[name=custom_css]' ).val( '' );
			$generator.find( 'input[name=custom_css_examples]:checked' ).prop( 'checked', false );
			$widget_code.trigger( 'rss-fwg-generate' );
		} );

		// advanced options hide/show
		$generator.find( '.collapse-trigger' ).on( 'click', function( e ) {
			e.preventDefault();

			var $this = $( this );
			if ( $this.hasClass( 'uncollapse' ) ) {
				// hide
				$this.parent().next().removeClass( 'showen' );
			} else {
				// show
				$this.parent().next().addClass( 'showen' );
			}
			$this.toggleClass( 'uncollapse' );
		} );

		// feed entry template
		var $feed_template = $generator.find( '.feed-item' );

		// new feed entry
		$generator.find( '.feed-new' ).on( 'click', function( e ) {
			e.preventDefault();

			// only at max 5 feeds allowed
			if ( $generator.find( '.feed-item' ).size() < 5 ) {
				// add new entry before this button
				$feed_template.clone().insertBefore( $( this ) ).find( 'input' ).val( '' );
				$widget_code.trigger( 'rss-fwg-generate' );
			}
		} );

		// remove feed entry
		$generator.on( 'click', '.feed-remove', function( e ) {
			e.preventDefault();

			// remove only if there are at lease one more
			if ( $generator.find( '.feed-item' ).size() > 1 ) {
				$( this ).closest( '.feed-item' ).remove();
				$widget_code.trigger( 'rss-fwg-generate' );
			}
		} );

		// // generate dropdown menus
		$generator.find( '.select2' ).each( function( index, element ) {
			var $element = $( element );

			$element.select2( $element.data() );
		} );

		// color inputs
		$generator.find( 'input[type=color]' ).spectrum( {
			preferredFormat: 'hex'
		} );

		// tooltip hints 
		$generator.find( '.section-hint' ).frosty();
	} );
} )( window );