<?php
/*
Plugin Name: FeedPress Generator
Plugin URI: http://www.jobthemes.com/themes/plugins/feedpress-generator/
Description: RSS Feed widget Code Generator - Allow users to  generate content from any type of rss feeds
Version: 1.0.1
Author: jobthemes.com
Author URI: http://www.jobthemes.com
Text Domain: feedpress-generator
Domain Path: /languages
Tags: rss feed, feedpress, rss widgets, feed generator, rss to content, feed to post, rss to widget, generate widget
License: GNU General Public License, version 2, http://www.gnu.org/licenses/gpl-2.0.html
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	die();

if ( ! function_exists( 'fg_fs' ) ) {
    // Create a helper function for easy SDK access.
    function fg_fs() {
        global $fg_fs;

        if ( ! isset( $fg_fs ) ) {
            // Include Freemius SDK.
            require_once dirname(__FILE__) . '/freemius/start.php';

            $fg_fs = fs_dynamic_init( array(
                'id'                  => '2954',
                'slug'                => 'feedpress-generator',
                'premium_slug'        => 'feedpress-geenrator-premium',
                'type'                => 'plugin',
                'public_key'          => 'pk_fe006bc34ec86c143a642752cbf9a',
                'is_premium'          => false,
                'has_addons'          => true,
                'has_paid_plans'      => false,
                'menu'                => array(
                    'slug'           => 'feedpress_generator_fwg_options',
                    'first-path'     => 'admin.php?page=feedpress_generator_fwg_options&tab=0',
                    'account'        => false,
                    'support'        => false,
                ),
            ) );
        }

        return $fg_fs;
    }

    // Init Freemius.
    fg_fs();
    // Signal that SDK was initiated.
    do_action( 'fg_fs_loaded' );
}




/**
 * Constants
 */

// plugin master file
define( 'FEEDPRESS_GENERATOR_FWG_MAIN_FILE', __FILE__ );

// plugin DIR
define( 'FEEDPRESS_GENERATOR_FWG_DIR', plugin_dir_path( FEEDPRESS_GENERATOR_FWG_MAIN_FILE ) );

// plugin URI
define( 'FEEDPRESS_GENERATOR_FWG_URI', plugin_dir_url( FEEDPRESS_GENERATOR_FWG_MAIN_FILE ) );

// localization text Domain
define( 'FEEDPRESS_FWG_DOMAIN', 'feedpress-generator' );

// Behaviour Mode
define( 'FEEDPRESS_GENERATOR_FWG_MODE', 'auto' );

/**
 * Includes
 */

// helper functions
require_once FEEDPRESS_GENERATOR_FWG_DIR . 'includes/helpers.php';

// Redux Framework
if ( !class_exists( 'ReduxFramework' ) && file_exists( FEEDPRESS_GENERATOR_FWG_DIR . 'includes/redux-framework/ReduxCore/framework.php' ) )
	require_once FEEDPRESS_GENERATOR_FWG_DIR . 'includes/redux-framework/ReduxCore/framework.php';

/**
 * Plugin Main Class
 * 
 * @class FEEDPRESS_GENRATOR_Feed_Widget_Generator
 * @since 1.0
 */
class FEEDPRESS_GENRATOR_Feed_Widget_Generator
{
	/**
	 * Plugin Version
	 * 
	 * @var string
	 */
	public $version = '1.0';

	/**
	 * @var FEEDPRESS_GENRATOR_Feed_Widget_Generator The single instance of the class
	 * @since 1.0
	 */
	protected static $_instance = null;

	/**
	 * Admin Pages
	 * 
	 * @since 1.0
	 * @var FEEDPRESS_GENERATOR_FWG_Backend
	 */
	var $backend;

	/**
	 * AJAX handler
	 * 
	 * @since 1.0
	 * @var FEEDPRESS_GENERATOR_FWG_Ajax_Handler
	 */
	var $ajax_handler;

	/**
	 * Shortcode
	 * 
	 * @since 1.0
	 * @var FEEDPRESS_GENERATOR_FWG_Shortcode
	 */
	var $shortcode;

	/**
	 * Behaviour loaded mode instance
	 * 
	 * @since 1.4.0
	 * @var object
	 */
	var $loaded_mode;

	/**
	 * Behaviour loaded mode name
	 * 
	 * @since 1.5.0
	 * @var string
	 */
	var $loaded_mode_name;

	/**
	 * Constructor
	 * 
	 * @since 1.0
	 * 
	 * @return FEEDPRESS_GENRATOR_Feed_Widget_Generator
	 */
	public function __construct()
	{
		// load language files
		add_action( 'plugins_loaded', array( &$this, 'load_language' ) );

		// Classes autoload
		spl_autoload_register( array( &$this, 'autoload' ) );

		// plugin loaded hook
		do_action( 'feedpress_generator_feed_widget_generator_loaded' );

		// modules
		$this->backend = new FEEDPRESS_GENERATOR_FWG_Backend( $this );
		$this->ajax_handler = new FEEDPRESS_GENERATOR_FWG_Ajax_Handler( $this );
		$this->shortcode = new FEEDPRESS_GENERATOR_FWG_Shortcode( $this );

		// Mode loader
		if ( defined( 'FEEDPRESS_GENERATOR_FWG_MODE' ) )
			add_action( 'init', array( &$this, 'load_mode_class' ), 8 );

		// Initial setups
		add_action( 'init', array( &$this, 'setups' ), 12 );

		// widget output
		add_action( 'template_redirect', 'FEEDPRESS_GENERATOR_FWG_Generator::output_endpoint' );
	}

	/**
	 * Load behaviour mode class base on FEEDPRESS_GENERATOR_FWG_MODE value
	 *
	 * @since 1.4.0
	 *
	 * @return void
	 */
	public function load_mode_class()
	{
		// don't load anything if mode was set to "normal"
		if ( 'normal' === FEEDPRESS_GENERATOR_FWG_MODE )
			return;

		// if set to auto
		if ( 'auto' === FEEDPRESS_GENERATOR_FWG_MODE && defined( 'APP_TD' ) )
		{
			// set mode based on current activated theme
			$mode_name = APP_TD;
		}
		else
		{
			// force to use a specific mode
			$mode_name = FEEDPRESS_GENERATOR_FWG_MODE;
		}

		/**
		 * Filters supported themes integration initialization classes map
		 * 
		 * @since 1.4.0
		 * 
		 * @param array $map
		 */
		$mode_classes_map = apply_filters( 'feedpress_generator_fwg_mode_classes_map', array ( 
				
		) );

		// check the mode is supported
		if ( isset( $mode_classes_map[ $mode_name ] ) )
		{
			// initialize mode
			$this->loaded_mode_name = $mode_name;
			$this->loaded_mode = new $mode_classes_map[ $mode_name ];
		}
	}

	/**
	 * Initial Setups
	 * 
	 * @since 1.2.0
	 * 
	 * @return void
	 */
	public function setups()
	{
		// Debugging suffix
		$suffix = FEEDPRESS_GENERATOR_FWG_Helpers::enqueue_suffix();
		$generator = FEEDPRESS_GENERATOR_FWG_Generator::instance();

		// Enqueues registrations

		// shared JS
		wp_register_script( 'rss-fwg-shared', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/shared'. $suffix .'.js', array( 'jquery' ), false, true );

		// Moment JS
		wp_register_script( 'rss-fwg-moment', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/moment.min.js', array( 'rss-fwg-shared' ), false, true );

		// scrollTo plugin
		wp_register_script( 'rss-fwg-scrollto', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/jquery.scrollTo.min.js', array( 'rss-fwg-shared' ), false, true );

		// Widget output
		wp_register_script( 'rss-fwg-widget', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/widget'. $suffix .'.js', array( 'rss-fwg-moment', 'rss-fwg-scrollto' ), false, true );
		wp_localize_script( 'rss-fwg-widget', 'feedpress_generator_feed_defaults', array (
				'settings' => $generator->get_settings_defaults(),
				'endpoint' => home_url( 'feeds-widget' ),
		) );
	}

	/**
	 * Autoload class files on demand
	 *
	 * `FEEDPRESS_GENERATOR_FWG_Starter` => includes/class-starter.php
	 * `FEEDPRESS_GENERATOR_FWG_Ajax_Handler` => includes/class-ajax-handler.php
	 * 
	 * @since 1.0
	 * 
	 * @param string $class requested class name
	 * @return void
	 */
	public function autoload( $class_name )
	{
		$prefix = 'feedpress_generator_fwg_';

		if ( stripos( $class_name, $prefix ) !== false )
		{
			$file_name = 'class-'. str_replace( array( $prefix, '_' ), array( '', '-' ), strtolower( $class_name ) ) .'.php';
			$file_path = apply_filters( 'feedpress_generator_fwg_generator_class_file_path', FEEDPRESS_GENERATOR_FWG_DIR . 'includes/'. $file_name, $file_name, $class_name );

			// check class file
			if ( !file_exists( $file_path ) )
				wp_die( 'Class file not found.<br/><code>'. $file_path .'</code>' );

			require_once $file_path;
		}
	}

	/**
	 * Language file loading
	 * 
	 * @since 1.0
	 * 
	 * @return void
	 */
	public function load_language()
	{
		$loaded = load_plugin_textdomain( FEEDPRESS_FWG_DOMAIN, false, dirname( plugin_basename( FEEDPRESS_GENERATOR_FWG_MAIN_FILE ) ) . '/languages' );
		// multi_dump_data( 'translation', $loaded );
	}

	/**
	 * Main FEEDPRESS_GENRATOR_Feed_Widget_Generator Instance
	 * 
	 * Ensures only one instance of FEEDPRESS_GENRATOR_Feed_Widget_Generator is loaded or can be loaded.
	 * 
	 * @since 1.0
	 * @static
	 * @see FEEDPRESS_GENERATOR_FEED_WIDGET()
	 * 
	 * @return FEEDPRESS_GENRATOR_Feed_Widget_Generator - Main instance
	 */
	public static function instance() 
	{
		if ( is_null( self::$_instance ) )
			self::$_instance = new self();

		return self::$_instance;
	}
}

/**
 * Returns the main instance of WC to prevent the need to use globals.
 *
 * @since  1.0
 * 
 * @return FEEDPRESS_GENRATOR_Feed_Widget_Generator
 */
function FEEDPRESS_GENERATOR_FEED_WIDGET()
{
	return FEEDPRESS_GENRATOR_Feed_Widget_Generator::instance();
}

/**
 * Get plugin settings short hand for easier access
 * 
 * @since 1.2.0
 * 
 * @param string $option_name
 * @return mixed
 */
function feedpress_generator_fwg_get_settings( $option_name = null )
{
	return FEEDPRESS_GENERATOR_FEED_WIDGET()->backend->get_settings( $option_name );
}

// startup plugin
$GLOBALS['feedpress_generator_feed_widget_generator'] = FEEDPRESS_GENERATOR_FEED_WIDGET();