<?php
/**
 * AJAX Hanlder
 * 
 * @package FEEDPRESS_GENRATOR_Feed_Widget_Generator/includes
 * @since 1.0
 */
class FEEDPRESS_GENERATOR_FWG_Ajax_Handler
{
	/**
	 * Plugin instance
	 * 
	 * @since 1.0
	 * @var FEEDPRESS_GENRATOR_Feed_Widget_Generator
	 */
	var $plugin;

	/**
	 * Constructor
	 * 
	 * @since 1.0
	 * 
	 * @param FEEDPRESS_GENRATOR_Feed_Widget_Generator plugin main class instance
	 * @return FEEDPRESS_GENERATOR_FWG_Ajax_Handler
	 */
	public function __construct( FEEDPRESS_GENRATOR_Feed_Widget_Generator &$plugin )
	{
		$this->plugin = $plugin;	
	}

	/**
	 * AJAX Debug response
	 * 
	 * @since 1.0
	 * 
	 * @param mixed $data
	 * @return void
	 */
	public static function debug( $data )
	{
		// return dump
		self::error( 'debug', $data );
	}

	/**
	 * AJAX Debug response ( dump )
	 * 
	 * @since 1.0
	 * 
	 * @return void
	 */
	public static function debug_dump()
	{
		// return dump
		self::error( 'debug', dump_data_export( func_get_args() ) );
	}

	/**
	 * AJAX Error response
	 * 
	 * @since 1.0
	 * 
	 * @param string $error_key
	 * @param mixed $error_message
	 * @param boolean $add_notice
	 * @return void
	 */
	public static function error( $error_key, $error_message, $add_notice = false )
	{
		// error obj
		$error = array( 'key' => $error_key, 'message' => $error_message );

		// send response
		self::response( $error, false, $add_notice );
	}

	/**
	 * AJAX JSON Response
	 * 
	 * @since 1.0
	 * 
	 * @param mixed $data
	 * @param boolean $status
	 * @param boolean $add_notice
	 * @return void
	 */
	public static function response( $data, $status = true, $add_notice = false )
	{
		// set response header content type
		header( 'Content-Type:application/json' );

		// response body
		$response = array ( 'status' => $status );

		// response type
		if ( $status )
		{
			// success response
			$response['data'] = $data;
		}
		else
		{
			// failure/error response
			$response['error'] = $data;
		}

		// send response
		die( json_encode( $response ) );
	}
}
