<?php
/**
 * Plugin Backend
 * 
 * @package FEEDPRESS_GENRATOR_Feed_Widget_Generator/includes
 * @since 1.0
 */
class FEEDPRESS_GENERATOR_FWG_Backend
{
	/**
	 * Settings API option key name
	 * 
	 * @since 1.0
	 * @var string
	 */
	const SETTINGS_OPTION_NAME = 'feedpress_generator_fwg_settings';

	/**
	 * Admin Page Slug
	 * 
	 * @since 1.2.0
	 * @var string
	 */
	const SETTINGS_PAGE_SLUG = 'feedpress_generator_fwg_options';

	/**
	 * Plugin instance
	 *
	 * @since 1.0
	 * @var FEEDPRESS_GENRATOR_Feed_Widget_Generator
	 */
	var $plugin;

	/**
	 * Settings fields
	 * 
	 * @since 1.0
	 * @var array
	 */
	var $settings_fields;

	/**
	 * Framework settings
	 * 
	 * @since 1.6.0
	 * @var array
	 */
	var $framework_settings;

	/**
	 * Settings options instance
	 * 
	 * @since 1.2.0
	 * @var ReduxFramework
	 */
	var $options_framework;

	/**
	 * Constructor
	 * 
	 * @param FEEDPRESS_GENRATOR_Feed_Widget_Generator plugin main class instance
	 * @return void
	 */
	public function __construct( FEEDPRESS_GENRATOR_Feed_Widget_Generator &$plugin )
	{
		$this->plugin = $plugin;

		// initial setups
		add_action( 'init', array ( &$this, 'setups' ), 11 );

		// options values filter
		add_filter( 'feedpress_generator_fwg_settings_values', array( &$this, 'options_values_defaults' ), 8, 2 );

		// modify Admin Bar menu
		add_action( 'admin_bar_menu', array( &$this, 'admin_bar_menu' ), 50 );
	}

	/**
	 * Modify Admin bar menu
	 * 
	 * @since 1.2
	 * 
	 * @param WP_Admin_Bar $wp_admin_bar
	 * @return void
	 */
	public function admin_bar_menu( $wp_admin_bar )
	{
		// check user permission
		$permission = isset( $this->framework_settings['page_permissions'] ) ? $this->framework_settings['page_permissions'] : 'manage_options';
		if ( !current_user_can( $permission ) )
			return;

		// add plugin settings page link
		$wp_admin_bar->add_node( array ( 
		 		'id' => 'feedpress_generator_fwg_settings',
				'title' => __( 'Feedpress- Classipress', FEEDPRESS_FWG_DOMAIN ),
				'parent' => 'site-name',
				'href' => admin_url( 'admin.php?page=' . $this->options_framework->args['page_slug'] ),
		) );
	}

	/**
	 * Setups and initializations
	 * 
	 * @since 1.0
	 * 
	 * @return void
	 */
	public function setups()
	{
		/**
		 * Settings API setups
		 */

		// fields
		// @see http://docs.reduxframework.com/category/core/fields/ for full list of availabe built-in fields
		$this->settings_fields = apply_filters( 'feedpress_generator_fwg_settings_template', array ( 
				array ( 
						'title' => __( 'Settings', FEEDPRESS_FWG_DOMAIN ),
						'icon' => 'el-icon-cogs',
						'fields' => array ( 
								array (
										'type' => 'text',
										'id' => 'default_feedpress_generator_feed',
										'title' => __( 'Default RSS feed', FEEDPRESS_FWG_DOMAIN ),
										'default' => get_feed_link( 'rss' ),
										'validate' => 'url',
								),
								array (
										'type' => 'radio',
										'id' => 'enable_settings',
										'title' => __( 'Advanced settings', FEEDPRESS_FWG_DOMAIN ),
										'options' => array ( 
												'basic' => __( 'Basic', FEEDPRESS_FWG_DOMAIN ),
												'advanced' => __( 'Advanced', FEEDPRESS_FWG_DOMAIN ),
										),
										'default' => 'basic',
								),
								array (
										'type' => 'text',
										'id' => 'bottom_text',
										'title' => __( 'Bottom text', FEEDPRESS_FWG_DOMAIN ),
										'default' => get_bloginfo( 'id' ),
								),
								array (
										'type' => 'text',
										'id' => 'bottom_link',
										'title' => __( 'Bottom link', FEEDPRESS_FWG_DOMAIN ),
										'default' => get_site_url(),
										'validate' => 'url',
								),

						),
				), 
				array ( 
						'title' => __( 'Donation', FEEDPRESS_FWG_DOMAIN ),
						'icon' => 'el-icon-usd',
						'fields' => array ( 
								array ( 
										'type' => 'switch',
										'id' => 'enable_donation',
										'title' => __( 'Enable donation', FEEDPRESS_FWG_DOMAIN ),
										'default' => false,
								),
								array ( 
										'type' => 'text',
										'id' => 'paypal_account',
										'title' => __( 'Paypal account', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'Your PayPal Email or Secure Merchant Account ID.', FEEDPRESS_FWG_DOMAIN ),
								),
								array (
										'type' => 'select',
										'id' => 'currency',
										'title' => __( 'Currency', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'The currency to use for the donations.', FEEDPRESS_FWG_DOMAIN ),
										'options' => array ( 
												'AUD' => __( 'Australian Dollars (A $)', FEEDPRESS_FWG_DOMAIN ),
												'BRL' => __( 'Brazilian Real', FEEDPRESS_FWG_DOMAIN ),
												'CAD' => __( 'Canadian Dollars (C $)', FEEDPRESS_FWG_DOMAIN ),
												'CZK' => __( 'Czech Koruna', FEEDPRESS_FWG_DOMAIN ),
												'DKK' => __( 'Danish Krone', FEEDPRESS_FWG_DOMAIN ),
												'EUR' => __( 'Euros (&euro;)', FEEDPRESS_FWG_DOMAIN ),
												'HKD' => __( 'Hong Kong Dollar ($)', FEEDPRESS_FWG_DOMAIN ),
												'HUF' => __( 'Hungarian Forint', FEEDPRESS_FWG_DOMAIN ),
												'ILS' => __( 'Israeli New Shekel', FEEDPRESS_FWG_DOMAIN ),
												'JPY' => __( 'Yen (&yen;)', FEEDPRESS_FWG_DOMAIN ),
												'MYR' => __( 'Malaysian Ringgit', FEEDPRESS_FWG_DOMAIN ),
												'MXN' => __( 'Mexican Peso', FEEDPRESS_FWG_DOMAIN ),
												'NOK' => __( 'Norwegian Krone', FEEDPRESS_FWG_DOMAIN ),
												'NZD' => __( 'New Zealand Dollar ($)', FEEDPRESS_FWG_DOMAIN ),
												'PHP' => __( 'Philippine Peso', FEEDPRESS_FWG_DOMAIN ),
												'PLN' => __( 'Polish Zloty', FEEDPRESS_FWG_DOMAIN ),
												'GBP' => __( 'Pounds Sterling (&pound;)', FEEDPRESS_FWG_DOMAIN ),
												'RUB' => __( 'Russian Ruble', FEEDPRESS_FWG_DOMAIN ),
												'SGD' => __( 'Singapore Dollar ($)', FEEDPRESS_FWG_DOMAIN ),
												'SEK' => __( 'Swedish Krona', FEEDPRESS_FWG_DOMAIN ),
												'CHF' => __( 'Swiss Franc', FEEDPRESS_FWG_DOMAIN ),
												'TWD' => __( 'Taiwan New Dollar', FEEDPRESS_FWG_DOMAIN ),
												'THB' => __( 'Thai Baht', FEEDPRESS_FWG_DOMAIN ),
												'TRY' => __( 'Turkish Lira', FEEDPRESS_FWG_DOMAIN ),
												'USD' => __( 'U.S. Dollars ($)', FEEDPRESS_FWG_DOMAIN ),
										),
								),
								array ( 
										'type' => 'text',
										'id' => 'page_style',
										'title' => __( 'Page style', FEEDPRESS_FWG_DOMAIN ),
										'desc' =>  __( 'The name of a custom payment page style that exist in your PayPal account profile.', FEEDPRESS_FWG_DOMAIN ),
								),
								array ( 
										'type' => 'text',
										'id' => 'return_page',
										'title' => __( 'Return page', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'URL to which the donator comes to after completing the donation.', FEEDPRESS_FWG_DOMAIN ),
								),
								array ( 
										'type' => 'text',
										'id' => 'amount',
										'title' => __( 'Amount', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'The default amount for a donation (Optional).', FEEDPRESS_FWG_DOMAIN ),
								),
								array ( 
										'type' => 'text',
										'id' => 'purpose',
										'title' => __( 'Purpose', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'The default purpose of a donation (Optional).', FEEDPRESS_FWG_DOMAIN ),
								),
								array ( 
										'type' => 'text',
										'id' => 'reference',
										'title' => __( 'Reference', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'Default reference for the donation (Optional).', FEEDPRESS_FWG_DOMAIN ),
								),
								array ( 
										'type' => 'image_select',
										'id' => 'donate_buttons',
										'title' => __( 'Select a button', FEEDPRESS_FWG_DOMAIN ),
										'options' => array ( 
												'btn_donate_SM.gif' => array ( 
														'alt' => __( 'Small', FEEDPRESS_FWG_DOMAIN ),
														'img' => 'https://www.paypal.com/en_US/i/btn/btn_donate_SM.gif',
												),
												'btn_donate_LG.gif' => array ( 
														'alt' => __( 'Large', FEEDPRESS_FWG_DOMAIN ),
														'img' => 'https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif',
												),	
												'btn_donateCC_LG.gif' => array ( 
														'alt' => __( 'Cards', FEEDPRESS_FWG_DOMAIN ),
														'img' => 'https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif',
												),
										),	
								),
								array ( 
										'type' => 'switch',
										'id' => 'use_custom_button',
										'title' => __( 'Use Custom button', FEEDPRESS_FWG_DOMAIN ),
										'default' => false,
								),
								array ( 
										'type' => 'media',
										'id' => 'custom_button_image',
										'title' => __( 'Banner Image', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'Upload the new button.', FEEDPRESS_FWG_DOMAIN ),
										'default' => '',
										'dependency' => array ( 
												'field' => 'use_custom_button',
												'function' => 'vp_dep_boolean',
										),
								),
								array ( 
										'type' => 'select',
										'id' => 'localization',
										'title' => __( 'Country and Language', FEEDPRESS_FWG_DOMAIN ),
										'default' => 'en_US',
										'desc' => __( 'Localize the language and the country for the button.', FEEDPRESS_FWG_DOMAIN ),
										'options' => array ( 
												'en_AU' 	=> __( 'Australia - Australian English', FEEDPRESS_FWG_DOMAIN ),
												'de_DE/AT'  => __( 'Austria - German', FEEDPRESS_FWG_DOMAIN ),
												'nl_NL/BE'  => __( 'Belgium - Dutch', FEEDPRESS_FWG_DOMAIN ),
												'fr_XC' 	=> __( 'Canada - French', FEEDPRESS_FWG_DOMAIN ),
												'zh_XC' 	=> __( 'China - Simplified Chinese', FEEDPRESS_FWG_DOMAIN ),
												'fr_FR/FR' 	=> __( 'France - French', FEEDPRESS_FWG_DOMAIN ),
												'de_DE/DE' 	=> __( 'Germany - German', FEEDPRESS_FWG_DOMAIN ),
												'it_IT/IT' 	=> __( 'Italy - Italian', FEEDPRESS_FWG_DOMAIN ),
												'ja_JP/JP' 	=> __( 'Japan - Japanese', FEEDPRESS_FWG_DOMAIN ),
												'es_XC' 	=> __( 'Mexico - Spanish', FEEDPRESS_FWG_DOMAIN ),
												'nl_NL/NL' 	=> __( 'Netherlands - Dutch', FEEDPRESS_FWG_DOMAIN ),
												'pl_PL/PL' 	=> __( 'Poland - Polish', FEEDPRESS_FWG_DOMAIN ),
												'es_ES/ES' 	=> __( 'Spain - Spanish', FEEDPRESS_FWG_DOMAIN ),
												'de_DE/CH' 	=> __( 'Switzerland - German', FEEDPRESS_FWG_DOMAIN ),
												'fr_FR/CH' 	=> __( 'Switzerland - French', FEEDPRESS_FWG_DOMAIN ),
												'en_US' 	=> __( 'United States - U.S. English', FEEDPRESS_FWG_DOMAIN ),
										),
								),
								array ( 
										'type' => 'switch',
										'id' => 'enable_advanced',
										'title' => __( 'Enable advanced settings', FEEDPRESS_FWG_DOMAIN ),
										'default' => false,
								),
								array ( 
										'type' => 'switch',
										'id' => 'disable_stats',
										'title' => __( 'Disable statistics', FEEDPRESS_FWG_DOMAIN ),
										'default' => false,
										'dependency' => array ( 
												'field' => 'enable_advanced',
												'function' => 'vp_dep_boolean',
										),
								),
								array ( 
										'type' => 'switch',
										'id' => 'new_window',
										'title' => __( 'Open PayPal in New Tab', FEEDPRESS_FWG_DOMAIN ),
										'default' => false,
										'dependency' => array ( 
												'field' => 'enable_advanced',
												'function' => 'vp_dep_boolean',
										),
								),
								array ( 
										'type' => 'switch',
										'id' => 'sandbox',
										'title' => __( 'Enable PayPal sandbox', FEEDPRESS_FWG_DOMAIN ),
										'desc' => __( 'Visit developer.paypal.com for more information.', FEEDPRESS_FWG_DOMAIN ),
										'default' => false,
										'dependency' => array ( 
												'field' => 'enable_advanced',
												'function' => 'vp_dep_boolean',
										),
								),
								array ( 
										'type' => 'switch',
										'id' => 'enable_checkout_language',
										'title' => __( 'Enable checkout language', FEEDPRESS_FWG_DOMAIN ),
										'default' => false,
										'dependency' => array ( 
												'field' => 'enable_advanced',
												'function' => 'vp_dep_boolean',
										),
								),
								array ( 
										'type' => 'select',
										'id' => 'checkout_language',
										'title' => __( 'Checkout language', FEEDPRESS_FWG_DOMAIN ),
										'dependency' => array ( 
												'field' => 'enable_advanced',
												'function' => 'vp_dep_boolean',
										),
										'options' => array ( 
												'AU' => __( 'Australia', FEEDPRESS_FWG_DOMAIN ),
												'AT' => __( 'Austria', FEEDPRESS_FWG_DOMAIN ),
												'BE' => __( 'Belgium', FEEDPRESS_FWG_DOMAIN ),
												'BR' => __( 'Brazil', FEEDPRESS_FWG_DOMAIN ),
												'CA' => __( 'Canada', FEEDPRESS_FWG_DOMAIN ),
												'CN' => __( 'China', FEEDPRESS_FWG_DOMAIN ),
												'FR' => __( 'France', FEEDPRESS_FWG_DOMAIN ),
												'DE' => __( 'Germany', FEEDPRESS_FWG_DOMAIN ),
												'IT' => __( 'Italy', FEEDPRESS_FWG_DOMAIN ),
												'NL' => __( 'Netherlands', FEEDPRESS_FWG_DOMAIN ),
												'PL' => __( 'Poland', FEEDPRESS_FWG_DOMAIN ),
												'PR' => __( 'Portugal', FEEDPRESS_FWG_DOMAIN ),
												'RU' => __( 'Russia', FEEDPRESS_FWG_DOMAIN ),
												'ES' => __( 'Spain', FEEDPRESS_FWG_DOMAIN ),
												'SE' => __( 'Sweden', FEEDPRESS_FWG_DOMAIN ),
												'CH' => __( 'Switzerland', FEEDPRESS_FWG_DOMAIN ),
												'GB' => __( 'United Kingdom', FEEDPRESS_FWG_DOMAIN ),
												'US' => __( 'United States', FEEDPRESS_FWG_DOMAIN ),
										),
								),
								array ( 
										'type' => 'select',
										'id' => 'return_method',
										'title' => __( 'Return method', FEEDPRESS_FWG_DOMAIN ),
										'default' => '',
										'desc' => __( 'Takes effect only if the return page is set.', FEEDPRESS_FWG_DOMAIN ),
										'dependency' => array ( 
												'field' => 'enable_advanced',
												'function' => 'vp_dep_boolean',
										),
										'options' => array ( 
												'0' => __( 'GET method (default)', FEEDPRESS_FWG_DOMAIN ),
												'1' => __( 'GET method, no variables', FEEDPRESS_FWG_DOMAIN ),
												'2' => __( 'POST method', FEEDPRESS_FWG_DOMAIN ),
										),
								),
						),	
				),
				array ( 
						'title' => __( 'FAQ', FEEDPRESS_FWG_DOMAIN ),
						'icon' => 'el-icon-question',
						'fields' => array ( 
								array ( 
										'id' => 'faq',
										'type' => 'raw',
										'content' => sprintf( __( 'Go to pages => paste this shortcode in the page and save it <code>[%s]</code>', FEEDPRESS_FWG_DOMAIN ), FEEDPRESS_GENERATOR_FWG_Shortcode::SHORTCODE_NAME ),
								),
						),
				),
		) );

		// options framework settings
		// @see http://docs.reduxframework.com/core/arguments/ for full arguments
		$this->framework_settings = array ( 
				'opt_name' 			=> self::SETTINGS_OPTION_NAME,
				'display_name' 		=> __( 'FeedPress Generator', FEEDPRESS_FWG_DOMAIN ),
				'display_version' 	=> $this->plugin->version,
				'menu_type' 		=> 'menu',
				'menu_title'		=> __( 'FeedPress Generator', FEEDPRESS_FWG_DOMAIN ),
				'page_title'		=> __( 'FeedPress Generator', FEEDPRESS_FWG_DOMAIN ),
				'page_slug'			=> self::SETTINGS_PAGE_SLUG,
				'page_permissions' 	=> 'manage_options',
				'page_icon' 		=> FEEDPRESS_GENERATOR_FWG_URI . 'assets/images/page-icon.png',
				'admin_bar' 		=> false,
				'dev_mode' 			=> WP_DEBUG,
				'update_notice' 	=> false,
				'disable_save_warn' => true,
				'footer_credit' 	=> __( 'FeedPress Generator', FEEDPRESS_FWG_DOMAIN ),
				'page_permissions' 	=> 'manage_options',
		);

		// initial options framework
		$this->options_framework = new ReduxFramework( $this->settings_fields, $this->framework_settings );

		/**
		 * Backend options framework instance
		 * 
		 * @since 1.2.0
		 * @param ReduxFramework $options_framework
		 */
		do_action_ref_array( 'feedpress_generator_fwg_backend', array( &$this->options_framework ) );
	}

	/**
	 * Returns the options array
	 *
	 * @since 1.0
	 * 
	 * @param string $option_name
	 * @return mixed
	 */
	public function get_settings( $option_name = null )
	{
		global $feedpress_generator_fwg_settings;

		if ( !isset( $feedpress_generator_fwg_settings ) )
			$feedpress_generator_fwg_settings = array();

		// load all options
		$options = &$feedpress_generator_fwg_settings;

		// default values
		$defaults = array();

		// fields loop
		foreach ( $this->settings_fields as $sections )
		{
			foreach ( $sections['fields'] as $field )
			{
				$defaults[ $field['id'] ] = isset( $field['default'] ) ? $field['default'] : '';
			}
		}

		// parse defaults
		$options = wp_parse_args( $options, $defaults );
		$options = array_intersect_key( $options, $defaults );

		// load single option
		if ( $option_name && isset( $options[ $option_name ] ) )
			return apply_filters( 'feedpress_generator_fwg_settings_values', $options[ $option_name ], $option_name );


		return apply_filters( 'feedpress_generator_fwg_settings_values', $options, $option_name );
	}

	/**
	 * Filter option value for default if not set
	 * 
	 * @since 1.5.5
	 * 
	 * @param mixed $option_value
	 * @param string $option_name
	 * @return mixed
	 */
	public function options_values_defaults( $option_value, $option_name )
	{
		// check for single option and null values only
		if ( empty( $option_name ) || !is_null( $option_value ) )
			return $option_value;

		// search fields for default value
		foreach ( $this->settings_fields as $section )
		{
			foreach ( $section['fields'] as $field )
			{
				// field found with default value
				if ( $option_name === $field['id'] && $field['default'] )
					return $field['default'];
			}
		}

		return $option_value;
	}
}


