<?php
/**
 * Frontend Shortcode renderer
 * 
 * @package FEEDPRESS_GENRATOR_Feed_Widget_Generator/includes
 * @since 1.0
 */
class FEEDPRESS_GENERATOR_FWG_Shortcode
{
	/**
	 * Plugin instance
	 * 
	 * @since 1.0
	 * @var FEEDPRESS_GENRATOR_Feed_Widget_Generator
	 */
	var $plugin;

	/**
	 * shortcode name
	 * 
	 * @since 1.0
	 * @var string
	 */
	const SHORTCODE_NAME = 'feedpress_generator_feed_widget_generator';

	/**
	 * Constructor
	 * 
	 * @since 1.0
	 * 
	 * @param FEEDPRESS_GENRATOR_Feed_Widget_Generator plugin main class instance
	 * @return FEEDPRESS_GENERATOR_FWG_Ajax_Handler
	 */
	public function __construct( FEEDPRESS_GENRATOR_Feed_Widget_Generator &$plugin )
	{
		$this->plugin = $plugin;

		// register shortcode
		add_shortcode( self::SHORTCODE_NAME , array( &$this, 'render' ) );
	
		// load css & js
		add_action( 'template_redirect', array( &$this, 'enqueues' ) );
	}

	/**
	 * Shortcode renderer
	 * 
	 * @since 1.0
	 * 
	 * @param array $attributes
	 * @return string
	 */
	public function render( $attributes )
	{
		// setups
		$basic_mode = 'basic' === feedpress_generator_fwg_get_settings( 'enable_settings' );
		$generator = FEEDPRESS_GENERATOR_FWG_Generator::instance();
		$options_fields = $generator->get_available_fields();
		$rendered_sections = array();
		$fields_list = array();

		$generator_wrapper_classes = array( 'clearfix' );
		if ( $this->plugin->loaded_mode_name )
		{
			$generator_wrapper_classes[] = 'mode-'. $this->plugin->loaded_mode_name;
			if ( FEEDPRESS_GENERATOR_FWG_MODE !== $this->plugin->loaded_mode_name )
				$generator_wrapper_classes[] = 'mode-'. FEEDPRESS_GENERATOR_FWG_MODE;
		}

		/**
		 * Filters widget generator wrapper div CSS classes
		 * 
		 * @since 1.5.0
		 * 
		 * @param array $classes
		 */
		$generator_wrapper_classes = (array) apply_filters( 'feedpress_generator_fwg_generator_wrapper_classes', $generator_wrapper_classes );

		// wrapper start
		$output = '<div id="rss-widget-generator" class="'. implode( ' ', $generator_wrapper_classes ) .'">';

		// options section
		$output .= '<div class="generator-section generator-options"><form>';

		if ( $basic_mode )
		{
			// sort fields based on order
			$field_order = array();
			foreach ( $options_fields as $field_name => $field_args )
				$field_order[ $field_name ] = $field_args['field_order'];

			array_multisort( $field_order, SORT_ASC, $options_fields );
		}

		// fields loop
		$field_output = '';
		foreach ( $options_fields as $field_name => $field_args )
		{
			// field input wrapper
			$field_classes = apply_filters( 'feedpress_generator_fwg_generator_option_classes', array ( 
					'option-field', 
					'option-'. $field_name, 
					'option-'. $field_args['input_type'], 
			), $field_name, $field_args );

			$field_output .= '<p class="'. implode( ' ', $field_classes ) .'">';

			// title
			$field_output .= '<label for="'. $field_name .'">'. $field_args['label'] .'</label>';

			// additional attributes
			$exta_attributes = FEEDPRESS_GENERATOR_FWG_Helpers::parse_attributes( $field_args['attributes'] );

			// field input based on input type
			$field_input = '';
			switch ( $field_args['input_type'] )
			{
				case 'select':
					// dropdown START
					$field_input .= '<select name="'. $field_name .'" id="'. $field_name .'" '. $exta_attributes .'>';

					// dropdown options
					foreach ( $field_args['options'] as $option_value => $option_label )
					{
						$field_input .= '<option value="'. esc_attr( $option_value ) .'" ';
						$field_input .= $option_value == $field_args['default'] ? 'selected ' : '';
						$field_input .= '> '. $option_label .'</option>';
					}

					// dropdown END
					$field_input .= '</select>';
					break;

				case 'radio':
					foreach ( $field_args['options'] as $option_value => $option_label )
					{
						$field_input .= '<label><input type="radio" name="'. $field_name .'" value="'. esc_attr( $option_value ) .'" ';
						$field_input .= $option_value == $field_args['default'] ? 'checked="checked" ' : '';
						$field_input .= '/> '. $option_label .'</label>&nbsp;&nbsp;';
					}
					break;

				case 'text':
				case 'number':
				case 'color':
					$field_input .= '<input type="'. $field_args['input_type'] .'" name="'. $field_name .'" id="'. $field_name .'" ';
					$field_input .= 'value="'. esc_attr( $field_args['default'] ) .'" '. $exta_attributes .'/>';
					break;
			}

			// field input based on name
			switch ( $field_name )
			{
				case 'feeds':
					$field_input = '<span class="feed-item clearfix">'. str_replace( 'name="feeds"', 'name="feeds[]"', $field_input );
					$field_input .= '<a href="javascript:void(0)" class="feed-remove">'. __( 'Remove', FEEDPRESS_FWG_DOMAIN ) .'</a></span>';
					$field_input .= '<a href="javascript:void(0)" class="feed-new">'. __( 'Add New Feed', FEEDPRESS_FWG_DOMAIN ) .'</a>';
					break;
			}

			/**
			 * Filter option input field layout
			 * 
			 * @since 1.2.5
			 * 
			 * @param string $field_input
			 * @param string $field_name
			 * @param array $field_args
			 * 
			 * @return string
			 */
			$field_output .= apply_filters( 'feedpress_generator_fwg_generator_option_input', $field_input, $field_name, $field_args );

			// description
			if ( !empty( $field_args['description'] ) )
				$field_output .= '&nbsp;<span class="description">'. $field_args['description'] .'</span>';

			// field input wrapper END
			$field_output .= '</p>';

			// section
			$field_section = &$field_args['section'];
			if ( !isset( $rendered_sections[ $field_section ] ) )
				$rendered_sections[ $field_section ] = array( 'basic' => array(), 'advanced' => array() );

			if ( $basic_mode )
			{
				// append to field list
				$fields_list[] = $field_output;
			}
			else
			{
				// append to it's related section section
				$rendered_sections[ $field_section ][ $field_args['option_type'] ][] = $field_output;
			}

			$field_output = '';
		}

		if ( $basic_mode )
		{
			// display fields list
			
			$output .= '<section class="options-section">';
			$output .= '<h3 class="section-title">'. __( 'Customize widget', FEEDPRESS_FWG_DOMAIN ) .'</h3>';
			$output .= '<div class="options-group options-basic clearfix">'. implode( '', $fields_list ) . '</div>';
			$output .= '</section>';
			
		}
		else
		{
			// display sections
			foreach ( $rendered_sections as $section_name => $section_fields )
			{
				$section_args = $generator->get_options_sections( $section_name );
				if ( !$section_args )
					continue;

				// wrapper
				$output .= '<section class="options-section">';
				

				// title
				if ( !empty( $section_args['title'] ) )
					$output .= '<h3 class="section-title">'. $section_args['title'] .'</h3>';

				// description hit
				if ( !empty( $section_args['description'] ) )
					$output .= '<a href="javascript:void(0)" class="section-hint" title="'. esc_attr( $section_args['description'] ) .'">?</a>';

				// subtitle
				if ( !empty( $section_args['subtitle'] ) )
					$output .= '<p class="section-subtitle">'. $section_args['subtitle'] .'</p>';

				// basic fields
				$output .= '<div class="options-group options-basic clearfix">'. implode( '', $section_fields['basic'] ) . '</div>';

				// advanced fields
				if ( sizeof( $section_fields['advanced'] ) )
				{
					// collapse/uncollapse button
					$output .= '<p class="options-collapse"><a href="javascript:void(0)" class="collapse-trigger">';
					$output .= __( 'Advanced Options', FEEDPRESS_FWG_DOMAIN ) .'</a></p>';

					// fields dump
					$output .= '<div class="options-group options-advanced clearfix">';
					$output .= implode( '', $section_fields['advanced'] ) . '</div>';
				}

				// wrapper END
				$output .= '</section>';
			}
		}

		// options sections END
		$output .= '</form></div>';

		// demo section
		$output .= '<div class="generator-section generator-preview">';

		// generated code
		$output .= '<section class="options-section section-preview">';
		$output .= '<h3 class="section-title">'. __( 'Widget Preview', FEEDPRESS_FWG_DOMAIN ) .'</h3>';
		$output .= '<div class="widget-preview"><div id="rss-feeds-widget"><div></div>';
		$output .= '</section>';

		// generated code
		$output .= '<section class="options-section section-code">';
		$output .= '<h3 class="section-title">'. __( 'Widget Generated Code', FEEDPRESS_FWG_DOMAIN );
		$output .= ' <small><a href="javascript:void(0)" class="widget-generate">'. __( 'Re-Generate', FEEDPRESS_FWG_DOMAIN ) .'</a></small></h3>';
		$output .= '<textarea class="widget-code code" readonly rows="14"></textarea>';
		$output .= '</section>';

		// donation button	
		if ( feedpress_generator_fwg_get_settings( 'enable_donation' ) == 1 )
			$output .= $this->donation_button();	

		// wrapper end
		$output .= '</div>';

		// demo section END
		$output .= '</div>';

		return apply_filters( 'feedpress_generator_fwg_generator_shortcode', $output );
	}

	/**
	 * PayPal Donation form
	 * 
	 * @since 1.2.0
	 * 
	 * return string
	 */
	public function donation_button()
	{
		$plugin_settings = feedpress_generator_fwg_get_settings();// dump_data( $plugin_settings );

		$url = $plugin_settings['sandbox'] ? 'https://www.sandbox.paypal.com/cgi-bin/webscr' : 'https://www.paypal.com/cgi-bin/webscr';

		// button wrapper START
		$button = '<br/><div class="donat">';

		// form START
		$button .= '<form action="'. esc_attr( apply_filters( 'feedpress_generator_fwg_paypal_donations_url', $url ) ) .'" method="post"';
		$button .=  ( $plugin_settings['new_window'] == 1 ? ' target="_blank"' : '' ) .'>';

		// hidden fields START
		$button .= '<div class="paypal-donations">';
		$button .= '<input type="hidden" name="cmd" value="_donations" />';
		$button .= '<input type="hidden" name="bn" value="jobthemes" />';
		$button .= '<input type="hidden" name="business" value="'. esc_attr( $plugin_settings['paypal_account'] ) .'" />';

		/**
		 * Button Options
		 */
		if ( !empty( $plugin_settings['page_style'] ) )
			$button .= '<input type="hidden" name="page_style" value="'. esc_attr( $plugin_settings['page_style'] ) .'" />';

		if ( !empty( $plugin_settings['return_page'] ) )
			$button .= '<input type="hidden" name="return" value="'. esc_attr( $plugin_settings['return_page'] ) .'" />';

		if ( !empty( $plugin_settings['purpose'] ) )
			$button .= '<input type="hidden" name="item_name" value="'. esc_attr( $plugin_settings['purpose'] ) .'" />';

		if ( !empty( $plugin_settings['reference'] ) )
			$button .= '<input type="hidden" name="item_number" value="'. esc_attr( $plugin_settings['reference'] ) .'" />';

		if ( !empty( $plugin_settings['amount'] ) )
			$button .= '<input type="hidden" name="amount" value="'. esc_attr( $plugin_settings['amount'] ) .'" />';

		if ( !empty( $plugin_settings['return_method'] ) )
			$button .= '<input type="hidden" name="rm" value="'. esc_attr( $plugin_settings['return_method'] ) .'" />';

		if ( !empty( $plugin_settings['currency'] ) )
			$button .= '<input type="hidden" name="currency_code" value="'. esc_attr( $plugin_settings['currency'] ) .'" />';

		if ( $plugin_settings['enable_checkout_language'] )
			$button .= '<input type="hidden" name="lc" value="'. esc_attr( $plugin_settings['checkout_language'] ) .'" />';

		$button_localized = empty( $plugin_settings['localization'] ) ? 'en_US' : $plugin_settings['localization'];
		$button_alt = __( 'PayPal - The safer, easier way to pay online.', FEEDPRESS_FWG_DOMAIN );

		// which button to use
		if ( $plugin_settings['use_custom_button'] == 1 && is_array( $plugin_settings['custom_button_image'] ) )
		{
			// custom button
			$button_src = $plugin_settings['custom_button_image']['url'];
		}
		else
		{
			// standard button 
			$button_src = 'https://www.paypal.com/'. $button_localized .'/i/btn/'. $plugin_settings['donate_buttons'];
		}

		// submit button
		$button .= '<input type="image" src="'. esc_attr( $button_src ) .'" name="submit" alt="'. esc_attr( $button_alt ) .'" />';

		// PayPal stats tracking
		if ( $plugin_settings['disable_stats'] == 1 )
			$button .= '<img alt="" class="pixelo" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1" />';

		// hidden fields END
		$button .= '</div>';

		// form END
		$button .= '</form>';

		// button wrapper END
		$button .= '</div>';

		return apply_filters( 'feedpress_generator_fwg_donation_button_html', $button );
	}

	/**
	 * Enqueue CSS and JavaScript files required for rendering
	 * 
	 * @since 1.0
	 * 
	 * @return void
	 */
	public function enqueues()
	{
		// enqueue only in the target page
		if ( !self::is_post_has_shortcode() )
			return;

		// Debugging suffix 
		$suffix = FEEDPRESS_GENERATOR_FWG_Helpers::enqueue_suffix();
		$generator = FEEDPRESS_GENERATOR_FWG_Generator::instance();

		// Styles
		wp_enqueue_style( 'rss-fwg-frosty', FEEDPRESS_GENERATOR_FWG_URI .'assets/css/frosty'. $suffix .'.css' );
		wp_enqueue_style( 'rss-fwg-spectrum', FEEDPRESS_GENERATOR_FWG_URI .'assets/css/spectrum'. $suffix .'.css' );
		wp_enqueue_style( 'rss-fwg-select2', FEEDPRESS_GENERATOR_FWG_URI .'assets/css/select2'. $suffix .'.css' );
		wp_enqueue_style( 'rss-fwg-generator', FEEDPRESS_GENERATOR_FWG_URI .'assets/css/generator'. $suffix .'.css' );

		// JavaScript
		wp_enqueue_script( 'rss-fwg-frosty', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/frosty'. $suffix .'.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'rss-fwg-spectrum', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/spectrum'. $suffix .'.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'rss-fwg-select2', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/select2'. $suffix .'.js', array( 'jquery' ), false, true );

		wp_enqueue_script( 'rss-fwg-generator', FEEDPRESS_GENERATOR_FWG_URI .'assets/js/generator'. $suffix .'.js', array( 'rss-fwg-shared', 'rss-fwg-widget' ), false, true );
		wp_localize_script( 'rss-fwg-generator', 'feedpress_generator_generator', array ( 
				'widget_script_uri' => $generator->get_widget_script_uri(),
		) );

		/**
		 * Fires after enqueuing generator page scripts and styles  
		 * 
		 * @since 1.2.5
		 */
		do_action( 'feedpress_generator_fwg_generator_enqueues' );
	}

	/**
	 * Determine if post has the target shortcode or not
	 * 
	 * @since 1.0
	 * 
	 * @param integer|WP_Post $_post if null will get the current post in query
	 * @return boolean
	 */
	public static function is_post_has_shortcode( $_post = null )
	{
		$post = get_post( $_post );

		return is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, self::SHORTCODE_NAME );
	}
}

	
