<?php
/**
 * Widget Content
 */

$generator = FEEDPRESS_GENERATOR_FWG_Generator::instance();

$feeds_fetching = $generator->fetch_feeds();
if ( is_wp_error( $feeds_fetching ) )
	die( $feeds_fetching->get_error_message() );

// holders
$feed_title = array();
$feed_entries = array();
$settings = $generator->get_widget_settings();

// reusable conditions
$user_ago_time = 'on' == $settings['entry_content_ago_enable'];
$use_html = 'on' == $settings['entry_content_html_enable'];
$entry_content_enabled = 'on' == $settings['entry_content_enable'];

// source icon
if ( 'on' == $settings['source_icon_enable'] )
	$entry_title_format = '<img src="'. FEEDPRESS_GENERATOR_FWG_URI .'assets/images/feed-icon-14x14.png" alt="" />&nbsp;%s';
else
	$entry_title_format = '%s';

// results loop
foreach ( $feeds_fetching as $feed_result )
{
	$feed_title[] = $feed_result['title'];

	// feed items loop
	foreach ( $feed_result['items'] as $entry_index => $entry )
	{
		// before entry layout placeholder
		$entry_layout = apply_filters( 'feedpress_generator_fwg_widget_entry_before', '', $entry );

		// entry title content
		$entry_title = wp_strip_all_tags( force_balance_tags( $entry['title'] ) );
		$entry_title_length = strlen( $entry_title );
		if ( $entry_title_length > (int) $settings['entry_title_length'] )
			$entry_title = substr( $entry_title, 0, (int) $settings['entry_title_length'] - 1 ) .'...';

		// entry title layout
		$entry_layout .= '<h3 class="entry-title">';
		$entry_layout .= '<a href="'. apply_filters( 'feedpress_generator_fwg_widget_entry_url', esc_attr( $entry['url'] ), $entry ) .'" class="entry-link">';
		$entry_layout .= sprintf( $entry_title_format, apply_filters( 'feedpress_generator_fwg_widget_entry_title', esc_html( $entry_title ), $entry ) );
		$entry_layout .= '</a></h3>';

		// entry content
		if ( $entry_content_enabled )
		{
			// use HTML or not
			if ( $use_html )
			{
				// allow only links and images
				$entry_content = wp_kses( $entry['content'], array ( 
						'a' => array( 'href' => true ), 
						'img' => array( 'src' => true ), 
				) );
			}
			else
				$entry_content = wp_strip_all_tags( $entry['content'] );

			// shorten content
			$entry_content = substr( $entry_content, 0, (int) $settings['entry_content_length'] - 1 ) .' ...';
			if ( $use_html )
				$entry_content = force_balance_tags( $entry_content );

			// entry content layout
			$entry_layout .= '<p class="entry-content">'. apply_filters( 'feedpress_generator_fwg_widget_entry_content', $entry_content, $entry ) .'</p>';
		}

		// entry time
		if ( $user_ago_time )
		{
			$entry_time = strtotime( $entry['datetime'] );
			$entry_layout .= '<time datetime="';
			$entry_layout .= apply_filters( 'feedpress_generator_fwg_widget_entry_time', esc_attr( date( 'Y-m-d', $entry_time ) ), $entry );
			$entry_layout .= '" class="entry-time"></time>';
		}

		// append to the entries list
		// after entry placeholder filter
		$feed_entries[] = apply_filters( 'feedpress_generator_fwg_widget_entry', $entry_layout, $entry ).
							apply_filters( 'feedpress_generator_fwg_widget_entry_after', '', $entry );
	}
}

// feed title settings
if ( 'on' == $settings['feed_title_enable'] )
{
	// specific feed title text
	if ( !empty( $settings['feed_title_text'] ) )
		$feed_title = array( esc_html( $settings['feed_title_text'] ) );
}
else
{
	// no feed title needed
	$feed_title = null;
}

// feed entries classes
$entry_classes = array( 'feed-item' );
if ( 'on' == $settings['entry_separator_line_enable'] )
	$entry_classes[] = 'separator';

$entry_classes = implode( ' ', $entry_classes );

// filter hooks
$feed_title = apply_filters( 'feedpress_generator_fwg_widget_feed_title', $feed_title );
$entry_classes = apply_filters( 'feedpress_generator_fwg_widget_entry_class', $entry_classes );
$list_classes = apply_filters( 'feedpress_generator_fwg_widget_list_class', 'feed-items' );
$container_classes = apply_filters( 'feedpress_generator_fwg_widget_container_class', 'container scroll-'. $settings['scroll_bar_dir'] );
?>

<div class="<?php echo $container_classes; ?>">
	<?php if ( $feed_title ) : ?>
		<h1 class="feed-title"><?php echo implode( ', ', $feed_title ); ?></h1>
	<?php endif; ?>

	<div class="list-wrapper">
		<ul class="<?php echo $list_classes; ?>">
			<?php echo '<li class="'. $entry_classes .'">', implode( '</li><li class="'. $entry_classes .'">', $feed_entries ), '</li>'; ?>
		</ul><!-- .feed-items -->
	</div>

	<?php if ( 'on' == $settings['footer_enable'] ) : ?>
		<p class="feed-footer"><?php echo apply_filters( 'feedpress_generator_fwg_widget_feed_footer', esc_html( $settings['footer_text'] ) ); ?></p>
	<?php endif; ?>
</div><!-- .container -->