<?php
/**
 * Widget Header
 */

$suffix = FEEDPRESS_GENERATOR_FWG_Helpers::enqueue_suffix();
$generator = FEEDPRESS_GENERATOR_FWG_Generator::instance();
$settings = $generator->get_widget_settings();

// styles
wp_register_style( 'rss-fwg-widget', FEEDPRESS_GENERATOR_FWG_URI .'assets/css/widget'. $suffix .'.css' );

// custom style example
if ( !empty( $settings['custom_css_examples'] ) && 0 === strpos( $settings['custom_css_examples'], FEEDPRESS_GENERATOR_FWG_URI ) )
	wp_register_style( 'rss-fwg-custom-example', esc_url( $settings['custom_css_examples'] ) );

// custom style
$user_custom_css = empty( $settings['custom_css'] ) ? null : wp_remote_retrieve_body( wp_remote_get( esc_url( $settings['custom_css'] ) ) );

?><!DOCTYPE html>
<!--[if IE 7]>
<html class="ie ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html class="ie ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 7) & !(IE 8)]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<!-- page attributes -->
	<meta http-equiv="X-UA-Compatible" content="IE=edge" />
	<meta name="viewport" content="width=device-width">
	<!-- widget main style -->
	<?php wp_print_styles( 'rss-fwg-widget' ); ?>
	<!-- user settings styles -->
	<style type="text/css">
	/* Body */
	body {
		font-family: '<?php echo esc_attr( $settings['font_face'] ); ?>', sans-serif !important;
		font-size: <?php echo esc_attr( $settings['font_size'] ); ?>px;
		background-color: <?php echo $settings['feed_bg_color']; ?>;
	}
	/* Feed title */
	.feed-title {
		color: <?php echo esc_attr( $settings['feed_title_color'] ); ?>;
		background-color: <?php echo esc_attr( $settings['feed_title_bg_color'] ); ?>;
<?php if ( !empty( $settings['feed_title_bg_image'] ) ) : ?>
		background-image: url("<?php echo esc_attr( $settings['feed_title_bg_image'] ); ?>");
<?php endif; ?>
	}
	/* Feed footer */
	.feed-footer {
		color: <?php echo esc_attr( $settings['footer_font_color'] ); ?>;
		background-color: <?php echo esc_attr( $settings['footer_bg_color'] ); ?>;
<?php if ( !empty( $settings['footer_bg_image'] ) ) : ?>
		background-image: url("<?php echo esc_attr( $settings['footer_bg_image'] ); ?>");
<?php endif; ?>
	}
<?php if ( 'on' == $settings['scroll_bar_enable'] ) : ?>
	/* Feed entry content */
	.feed-items {
		overflow: auto;
	}
	.scroll-horizontal .list-wrapper {
		overflow: auto;
	}
<?php endif; ?>
	/* Feed entry content */
	.feed-items .entry-content { 
		color: <?php echo esc_attr( $settings['entry_content_color'] ); ?>;
	}
	/* Feed entry content links */
	.feed-items .entry-content a { 
		color: <?php echo esc_attr( $settings['entry_content_link_color'] ); ?>;
	}
	/* Feed entry title */
	.feed-items .entry-title {
		color: <?php echo esc_attr( $settings['entry_title_color'] ); ?>;
		background-color: <?php echo esc_attr( $settings['entry_title_bg_color'] ); ?>;
<?php if ( !empty( $settings['entry_title_bg_image'] ) ) : ?>
		background-image: url("<?php echo esc_attr( $settings['entry_title_bg_image'] ); ?>");
<?php endif; ?>
	}
	/* Widget footer color */
	.widget-footer, .widget-footer a {
		color: <?php echo esc_attr( $settings['bottom_link_color'] ); ?>;
	}
	.bordered .container,
	.feed-items .feed-item.separator {
		border-color: <?php echo esc_attr( $settings['border_color'] ); ?>;
	}
	</style>
	<?php wp_print_styles( 'rss-fwg-custom-example' ); ?>
	<!-- user defined CSS -->
	<?php if ( $user_custom_css ) : ?>
	<style type="text/css"><?php echo feedpress_generator_fwg_sanitize_css( $user_custom_css ); ?></style>
	<?php endif; ?>
	<?php
	/**
	 * Allow plugins to add there own header tags
	 * 
	 * @since 1.6.0
	 */
	do_action( 'feedpress_generator_fwg_widget_head' );
	?>
</head>

<body <?php body_class( 'on' == $settings['border_enable'] ? 'bordered' : '' ); ?>>
	<div class="wrapper">		